aboutsummaryrefslogtreecommitdiff
path: root/src/nvim/api/vim.c
diff options
context:
space:
mode:
Diffstat (limited to 'src/nvim/api/vim.c')
-rw-r--r--src/nvim/api/vim.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/nvim/api/vim.c b/src/nvim/api/vim.c
index ab67bc2a3e..602733fd31 100644
--- a/src/nvim/api/vim.c
+++ b/src/nvim/api/vim.c
@@ -1419,7 +1419,7 @@ Dictionary nvim_get_color_map(void)
/// Gets a map of the current editor state.
///
/// @param opts Optional parameters.
/// - types: List of |context-types| ("regs", "jumps", "buflist",
/// "gvars", …) to gather, or empty for "all".
/// @param[out] err Error details, if any
///
@@ -1453,8 +1453,8 @@ Dictionary nvim_get_context(Dictionary opts, Error *err)
int_types |= kCtxRegs;
} else if (strequal(s, "jumps")) {
int_types |= kCtxJumps;
- } else if (strequal(s, "buflist")) {
- int_types |= kCtxBuflist;
+ } else if (strequal(s, "bufs")) {
+ int_types |= kCtxBufs;
} else if (strequal(s, "gvars")) {
int_types |= kCtxGVars;
} else if (strequal(s, "sfuncs")) {
@@ -1419,7 +1419,7 @@ Dictionary nvim_get_color_map(void)
///
/// @param opts Optional parameters.
-/// - types: List of |context-types| ("regs", "jumps", "buflist",
+/// - types: List of |context-types| ("regs", "jumps", "bufs",
/// "gvars", …) to gather, or empty for "all".
/// @param[out] err Error details, if any